@@ -1,5 +1,5 @@
 # gTranscribe is a software focussed on easy transcription of spoken words.
-# Copyright (C) 2013-2016 Philip Rinn <rinni@inventati.org>
+# Copyright (C) 2013-2018 Philip Rinn <rinni@inventati.org>
 # Copyright (C) 2010 Frederik Elwert <frederik.elwert@web.de>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,6 +17,7 @@
 import os.path
 import datetime
 import hashlib
+import re
 import gettext
 from gettext import gettext as _
 import gi
@@ -29,7 +30,7 @@ def trim(timestring, digits=1):
     """
     Trim a time string to contain only a given number of digits
     """
-    pos = timestring.find('.')
+    pos = re.search("[.-]", timestring).start()
     if pos > -1:
         return timestring[:pos + 1 + digits]
     else:
@@ -101,6 +102,7 @@ def get_save_filename(self):
                                     Gtk.FileChooserAction.SAVE,
                                     (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                      Gtk.STOCK_SAVE, Gtk.ResponseType.OK))
+    chooser.set_do_overwrite_confirmation(True)
     response = chooser.run()
     if response == Gtk.ResponseType.OK:
         filename = chooser.get_filename()
