@@ -24,6 +24,7 @@ Gst.init(None)
 
 
 class gTranscribePlayer(Gst.Bin):
+    """Class to play audio files with Gstreamer."""
 
     __gtype_name__ = 'gTranscribePlayer'
 
@@ -40,39 +41,40 @@ class gTranscribePlayer(Gst.Bin):
         self.init_pipeline()
 
     def init_pipeline(self):
+        """Initialize the audio pipeline."""
         self.pipeline = Gst.Pipeline()
         self.audiosrc = Gst.ElementFactory.make('filesrc', None)
-        self.decoder = Gst.ElementFactory.make('decodebin', None)
-        self.convert1 = Gst.ElementFactory.make('audioconvert', None)
-        self.resample1 = Gst.ElementFactory.make('audioresample', None)
+        decoder = Gst.ElementFactory.make('decodebin', None)
+        convert1 = Gst.ElementFactory.make('audioconvert', None)
+        resample1 = Gst.ElementFactory.make('audioresample', None)
         self.volume1 = Gst.ElementFactory.make('volume', None)
         self.volume1.set_property('volume', 1)
-        self.scaletempo = Gst.ElementFactory.make('scaletempo', None)
-        self.convert2 = Gst.ElementFactory.make('audioconvert', None)
-        self.resample2 = Gst.ElementFactory.make('audioresample', None)
-        self.sink = Gst.ElementFactory.make('autoaudiosink', None)
+        scaletempo = Gst.ElementFactory.make('scaletempo', None)
+        convert2 = Gst.ElementFactory.make('audioconvert', None)
+        resample2 = Gst.ElementFactory.make('audioresample', None)
+        sink = Gst.ElementFactory.make('autoaudiosink', None)
 
-        self.decoder.connect('pad-added', self.on_new_decoded_pad)
+        decoder.connect('pad-added', self.on_new_decoded_pad)
 
         self.pipeline.add(self.audiosrc)
-        self.pipeline.add(self.decoder)
-        self.pipeline.add(self.convert1)
+        self.pipeline.add(decoder)
+        self.pipeline.add(convert1)
         self.pipeline.add(self.volume1)
-        self.pipeline.add(self.resample1)
-        self.pipeline.add(self.scaletempo)
-        self.pipeline.add(self.convert2)
-        self.pipeline.add(self.resample2)
-        self.pipeline.add(self.sink)
+        self.pipeline.add(resample1)
+        self.pipeline.add(scaletempo)
+        self.pipeline.add(convert2)
+        self.pipeline.add(resample2)
+        self.pipeline.add(sink)
 
-        self.audiosrc.link(self.decoder)
-        self.convert1.link(self.resample1)
-        self.resample1.link(self.volume1)
-        self.volume1.link(self.scaletempo)
-        self.scaletempo.link(self.convert2)
-        self.convert2.link(self.resample2)
-        self.resample2.link(self.sink)
+        self.audiosrc.link(decoder)
+        convert1.link(resample1)
+        resample1.link(self.volume1)
+        self.volume1.link(scaletempo)
+        scaletempo.link(convert2)
+        convert2.link(resample2)
+        resample2.link(sink)
 
-        self.apad = self.convert1.get_static_pad('sink')
+        self.apad = convert1.get_static_pad('sink')
 
         bus = self.pipeline.get_bus()
         bus.add_signal_watch()
@@ -80,6 +82,7 @@ class gTranscribePlayer(Gst.Bin):
 
     @property
     def filename(self):
+        """Return the filename of the current stream."""
         return self.audiosrc.get_property('location')
 
     @property
@@ -87,7 +90,7 @@ class gTranscribePlayer(Gst.Bin):
         """Return the duration of the current stream."""
         if self._duration is None:
             self._duration = self.pipeline.query_duration(Gst.Format.TIME)[1]
-            logger.debug('Duration is: "%s"' % self._duration)
+            logger.debug('Duration is: "%s"', self._duration)
         return self._duration
 
     def _get_position(self):
@@ -99,6 +102,7 @@ class gTranscribePlayer(Gst.Bin):
         return pos[1]
 
     def _set_position(self, position):
+        """Set the position of the current stream."""
         self.pipeline.seek(self._rate,
                            Gst.Format.TIME,
                            Gst.SeekFlags.FLUSH | Gst.SeekFlags.ACCURATE,
@@ -113,37 +117,43 @@ class gTranscribePlayer(Gst.Bin):
         return Gst.State.PLAYING == self.state
 
     def _get_rate(self):
+        """Get the playback speed of the current stream."""
         return self._rate
 
     def _set_rate(self, rate):
+        """Set the playback speed of the current stream."""
         self._rate = rate
         seek_type = Gst.SeekType.SET
-        try:
-            pos = self.pipeline.query_position(Gst.Format.TIME)[1]
-        except:
+        pos = self.pipeline.query_position(Gst.Format.TIME)
+        # Position query was not successful
+        if pos[0] == 0:
             seek_type = Gst.SeekType.NONE
-            pos = -1
+            pos[1] = -1
         self.pipeline.seek(rate,
                            Gst.Format.TIME,
                            Gst.SeekFlags.FLUSH | Gst.SeekFlags.ACCURATE,
-                           seek_type, pos,
+                           seek_type, pos[1],
                            Gst.SeekType.NONE, -1)
 
     rate = property(_get_rate, _set_rate)
 
     def _get_state(self):
+        """Get the state of the audio pipeline."""
         return self.pipeline.get_state(0)[1]
 
     def _set_state(self, state):
+        """Set the state of the audio pipeline."""
         if not state == self.state:
             self.pipeline.set_state(state)
 
     state = property(_get_state, _set_state)
 
     def _get_volume(self):
+        """Get the volume of the current stream."""
         return self.volume1.get_property('volume')
 
     def _set_volume(self, volume):
+        """Set the volume of the current stream."""
         self.volume1.set_property('volume', volume)
 
     volume = property(_get_volume, _set_volume)
@@ -162,15 +172,17 @@ class gTranscribePlayer(Gst.Bin):
             self.emit('ready', self.filename)
 
     def on_message(self, bus, message):
+        """Handle message and react accordingly."""
         if message.type == Gst.MessageType.EOS:
             self.state = Gst.State.NULL
             self.emit('ended')
         elif message.type == Gst.MessageType.ERROR:
-            logger.debug("%s" % print(message.parse_error()))
+            logger.debug("%s", print(message.parse_error()))
             self.state = Gst.State.NULL
 
     def open(self, filepath, duration=True):
-        logger.debug('Opening file "%s"' % filepath)
+        """Open audio file and optionally query duration."""
+        logger.debug('Opening file "%s"', filepath)
         self.state = Gst.State.READY
         self.audiosrc.set_property('location', filepath)
         if duration:
@@ -194,3 +206,9 @@ class gTranscribePlayer(Gst.Bin):
     def pause(self):
         """Pause playback."""
         self.state = Gst.State.PAUSED
+
+    def move_position(self, amount):
+        """Move playback position."""
+        new_position = self.position + amount
+        # Clamp new_position between 0 and self.duration
+        self.position = max(min(new_position, self.duration), 0)
